#!/usr/bin/env python3

"""
A module for creating various symmetric Toeplitz matrices.
"""

import numpy as np

def general(L):
    """
    Returns a symmetric Toeplitz matrix with the first row equal to the elements of list `L`.
    """
    n = len(L)
    return np.matrix([[L[abs(i-j)] for i in range(n)] for j in range(n)])

def tridiagonal(n, d, sd):
    """
    Returns a tridiagonal symmetric Toeplitz matrix of order `n`,
    with the float number `d` on the diagonal and
    the float number `sd` right below and above it (the rest of the elements are zero).
    """
    res = sd * np.matrix(np.tri(n, n, 1) - np.tri(n, n, -2))
    np.fill_diagonal(res, d)
    return res

def filled(n, d, nd):
    """
    Returns a symmetric Toeplitz matrix of order `n`
    with the float number `d` on the diagonal and
    all the non-diagonal elements equal to `nd`.
    """
    res = nd * np.matrix(np.ones((n,n)))
    np.fill_diagonal(res, d)
    return res

def menu():
    """
    Returns a symmetric Toeplitz matrix loaded from user by giving them
    a choice between the three types supported by this module.
    """
    while True:
        print("Load a symmetric Toeplitz matrix:")
        print("  1. General symmetric Toeplitz matrix")
        print("  2. Tridiagonal symmetric Toeplitz matrix")
        print("  3. Filled symmetric Toeplitz matrix")
        choice = input("Your choice (1-3): ")
        if choice == "1":
            while True:
                row = input("The first row: ")
                if row != "":
                    try:
                        return general([ float(num) for num in row.split(",") ])
                    except Exception:
                        pass
        elif choice == "2":
            while True:
                try:
                    n = int(input("n:  "))
                    if n <= 0:
                        continue
                    d = float(input("d:  "))
                    sd = float(input("sd: "))
                    return tridiagonal(n, d, sd)
                except Exception:
                    pass
        elif choice == "3":
            while True:
                try:
                    n = int(input("n:  "))
                    if n <= 0:
                        continue
                    d = float(input("d:  "))
                    nd = float(input("nd: "))
                    return filled(n, d, nd)
                except Exception:
                    pass
        else:
            pass

